package cn.iocoder.yudao.module.inspection.service;

import java.util.List;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;
import cn.iocoder.yudao.module.inspection.entity.InspectionEquInfo;

/**
 * equInfoService接口
 *
 * @author zcy
 * @date 2023-10-13
 */
public interface IInspectionEquInfoService extends IService<InspectionEquInfo>
{
    /**
     * 查询equInfo
     *
     * @param id equInfo主键
     * @return equInfo
     */
    public InspectionEquInfo selectInspectionEquInfoById(Long id);

    /**
     * 查询equInfo列表
     *
     * @param inspectionEquInfo equInfo
     * @return equInfo集合
     */
    public IPage<InspectionEquInfo> selectInspectionEquInfoList(Page page,InspectionEquInfo inspectionEquInfo);

    /**
     * 新增equInfo
     *
     * @param inspectionEquInfo equInfo
     * @return 结果
     */
    public int insertInspectionEquInfo(InspectionEquInfo inspectionEquInfo);

    /**
     * 修改equInfo
     *
     * @param inspectionEquInfo equInfo
     * @return 结果
     */
    public int updateInspectionEquInfo(InspectionEquInfo inspectionEquInfo);

    /**
     * 批量删除equInfo
     *
     * @param ids 需要删除的equInfo主键集合
     * @return 结果
     */
    public int deleteInspectionEquInfoByIds(Long[] ids);

    /**
     * 删除equInfo信息
     *
     * @param id equInfo主键
     * @return 结果
     */
    public int deleteInspectionEquInfoById(Long id);
}
